#
# spec file for package p7zip
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           p7zip
Version:        9.20.1
Release:        17.1
Summary:        7-zip file compression program
License:        LGPL-2.1+
Group:          Productivity/Archiving/Compression
Url:            http://p7zip.sourceforge.net/
Source:         http://switch.dl.sourceforge.net/sourceforge/%{name}/%{name}_%{version}_src_all.tar.bz2
Patch0:         p7zip-CVE-2015-1038.patch
# PATCH-FIX-UPSTREAM bnc#979823 kstreitova@suse.com -- out-of-bounds read vulnerability
Patch1:         p7zip-9.20.1-CVE-2016-2335.patch
BuildRequires:  gcc-c++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1100
BuildRequires:  fdupes
%endif

%description
p7zip is a quick port of 7z.exe and 7za.exe (command line version of
7zip, see www.7-zip.org) for Unix. 7-Zip is a file archiver with
highest compression ratio. Since 4.10, p7zip (like 7-zip) supports
little-endian and big-endian machines.

%prep
%setup -q -n %{name}_%{version}
%patch0
%patch1 -p1

%ifarch x86_64
cp makefile.linux_amd64_asm makefile.machine
%endif

%ifarch ppc64 s390x
cp makefile.linux_amd64 makefile.machine
%else
cp makefile.linux_any_cpu_gcc_4.X makefile.machine
%endif

sed -i s,444,644,g install.sh
sed -i s,555,755,g install.sh

perl -pi -e 's/ -s / /' makefile.machine
perl -pi -e 's/(\$\(LOCAL_FLAGS\))/'"%{optflags}"' \\\n\t$1/' makefile.machine

%build
make %{?_smp_mflags} all2

%install
mkdir -p %{buildroot}/%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man1
./install.sh \
	%{_bindir} \
	%{_libdir}/%{name} \
	%{_mandir} \
        %{_defaultdocdir}/%{name} \
        %{buildroot}
%if 0%{?suse_version} > 1100
%fdupes -s %{buildroot}
%endif

%check
%if ! 0%{?qemu_user_space_build}
make test
make test_7z
%endif

%files
%defattr(-,root,root)
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/Codecs
%{_libdir}/%{name}/[0-9a-z]*
%{_libdir}/%{name}/Codecs/*
%{_bindir}/7z
%{_bindir}/7za
%doc %{_defaultdocdir}/%{name}
%{_mandir}/man1/*

%changelog
* Mon May 23 2016 kstreitova@suse.com
- add p7zip-9.20.1-CVE-2016-2335.patch to fix 7zip UDF
  CInArchive::ReadFileItem code execution vulnerability
  [bnc#979823], [CVE-2016-2335]
* Tue Jun 23 2015 pgajdos@suse.com
- fixed CVE-2015-1038 [bnc#912878]
  + p7zip-CVE-2015-1038.patch
* Sat Oct  1 2011 crrodriguez@opensuse.org
- test suite segfaults on qemu-arm, we will see if it is a bug
  in p7zip or a glitch in qemu later.
* Wed Sep 28 2011 idonmez@suse.com
- Enable assembly support for x86-64
- Update to version 9.20
  - From Windows version of 7-zip 9.20, What's new after 7-Zip 4.65 (2009-02-03):
  - 7-Zip now supports LZMA2 compression method.
  - 7-Zip now can update solid .7z archives.
  - 7-Zip now supports XZ archives.
  - 7-Zip now supports PPMd compression in ZIP archives.
  - 7-Zip now can unpack NTFS, FAT, VHD, MBR, APM, SquashFS, CramFS, MSLZ archives.
  - 7-Zip now can unpack GZip, BZip2, LZMA, XZ and TAR archives from stdin.
  - 7-Zip now can unpack some TAR and ISO archives with incorrect headers.
  - 7-Zip now supports files that are larger than 8 GB in TAR archives.
  - NSIS and WIM support was improved.
  - Partial parsing for EXE resources, SWF and FLV.
  - The support for archives in installers was improved.
  - 7-Zip now can stores NTFS file timestamps to ZIP archives.
  - Speed optimizations in PPMd codec.
  - Speed optimizations in CRC calculation code for Intel's Atom CPUs.
  - New -scrc switch to calculate total CRC-32 during extracting / testing.
  - 7-Zip File Manager now doesn't use temp files to open nested archives stored without compression.
  - Disk fragmentation problem for ZIP archives created by 7-Zip was fixed.
  - Some bugs were fixed.
  - New localizations: Hindi, Gujarati, Sanskrit, Tatar, Uyghur, Kazakh.
  - Not in p7zip : Speed optimizations in AES code for Intel's 32nm CPUs.
  - From Windows version of 7-zip 9.17
  - Disk fragmentation problem for ZIP archives created by 7-Zip was fixed.
    Notes: 7-Zip now uses 4 MB RAM buffer as file cache, when you create ZIP archives.
    It reduces the number of Move_File_Position and Write_to_File operations.
  - From Windows version of 7-zip 9.18
  - 7-Zip now can unpack SquashFS and CramFS filesystem images.
  - 7-Zip now can unpack some TAR and ISO archives with incorrect headers.
  - Some bugs were fixed.
  - From Windows version of 7-zip 9.16
  - 7-Zip now supports files that are larger than 8 GB in TAR archives.
  - NSIS support was improved :
  - 7-Zip now supports BZip2 method in NSIS installers.
  - 7-Zip now can extract identical files from NSIS installers.
  - Some bugs were fixed.
  - New localizations: Hindi, Gujarati, Sanskrit.
  - From Windows version of 7-zip 9.15
  - Some bugs were fixed.
  - New localization: Tatar
  - From Windows version of 7-zip 9.14
  - WIM support was improved. 7-Zip now can create WIM archives without compression.
  - sf#3069545 "kSignatureDummy?" fixed
* Wed May 25 2011 chris@computersalat.de
- fix deps
  o no fdupes on suse_version < 1100 (SLES9, SLE10)
- remove Author from description
* Mon May 31 2010 freespacer@gmx.de
- update to version 9.13
  * From Windows version of 7-zip 9.12
  - Some bugs were fixed.
  * #2863580 "Crash in Rar decoder on a corrupted file" fixed
  * #2860898 "Dereferencing a zero pointer in cab handler" fixed
  * #2860679 "Division by zero in cab decoder" fixed
- update to version 9.12
  * From Windows version of 7-zip 9.12
  - ZIP / PPMd compression ratio was improved in Maximum and Ultra modes.
  - The BUG in 7-Zip 9.* beta was fixed: LZMA2 codec didn't work,
    if more than 10 threads were used (or more than 20 threads in some modes).
  * makefile.openbsd is now compatible with OpenBSD ports tree.
    (thanks to jggimi)
  * cmake projects added.
  * 7zFM and 7zG can be built on MacOSX but these ports are in very alpha stage.
    make app to build p7zip.app (p7zip for MacOSX)
- update to version 9.11 (never published)
  * From Windows version of 7-zip 9.11
  - 7-Zip now supports PPMd compression in .ZIP archives.
  - Speed optimizations in PPMd codec.
  - The support for archives in installers was improved.
  - Some bugs were fixed.
- update to version 9.10 (never published)
  * From Windows version of 7-zip 9.05 to 9.10
  - 7-Zip now can unpack Apple Partition Map (APM) disk images.
  - 7-Zip now can unpack MSLZ archives.
  - Partial parsing for EXE resources, SWF and FLV.
  - Some bugs were fixed.
  * p7zip can now use hugetlbfs on Linux (thank to Joachim Henke)
    Like with the Windows large pages, this gives a nice speedup,
    when running memory intensive operations.
  * p7zip now uses UTF8 (kCFStringNormalizationFormD) On MacOSX
    fixes  #2831266 "p7zip can't find NFC Unicode  filename in OSX Terminal"
    and    #2976169 "German Umlauts Failure"
- update to version 9.05 (never published)
  * p7zip now uses precompiled header with gcc 4
- remove obsolete patch (gcc_missing_include.patch)
- renew patch (install.patch)
* Thu Jun 18 2009 freespacer@gmx.de
- update to version 9.04
  * 7-Zip now can update solid .7z archives
  * 7-Zip now supports LZMA2 compression method
  * 7-Zip now supports XZ archives
  * 7-Zip now can unpack NTFS, FAT, VHD and MBR archives
  * 7-Zip now can unpack GZip, BZip2, LZMA, XZ and TAR archives from stdin
  * New -scrc switch to calculate total CRC-32 during extracting / testing
  * Some bugs were fixed
  * #2799966 " A newly created 7z archive (by p7zip 4.65) is broken and cannot be unpacked / listed / tested"
    Fixed: now "7za a -mx=9 archive.7z directory" creates a good archive even
    if there are a lot of executable files
  * Fixed: the RAM size was reported incorrectly on MacOSX 64bits (with 2Gb+ RAM)
  * #2798023 "segfault handling very large multivolume .7z file"
    p7zip now displays the following error "Error: Too many open files"
    if you don't have enough rights to open all the splitted files
    (on Linux: ulimit -n)
  - included update from 4.65
  * The bug in 7-Zip 4.63 was fixed: 7-Zip could not decrypt .ZIP archives encrypted with WinZip-AES method
  * 7-Zip now can unpack ZIP archives encrypted with PKWARE-AES
  * Some bugs were fixed
  * Fixed: the RAM size was reported incorrectly on MacOSX 64bits
  * Fixed: makefile.linux_amd64_asm_icc
  * DJGPP: makefile.djgpp becomes makefile.djgpp_old
  * DJGPP: makefile.djgpp_watt added (thank to Rugxulo)
  * you can now compile 7za with a cmake project (see README)
  - included update from 4.61
  * 7-Zip now supports LZMA compression for .ZIP archives
  * Ask for password twice when creating encrypted archive
  * 7zG added (read GUI/readme.txt)
  * p7zip didn't use the BCJ /BCJ2 filters for executables (:
  * makefile.linux_amd64_asm_icc added (tested with Intel Compiler 11 on Ubuntu 8.04 x64)
  * 7-Zip now can unpack UDF, XAR and DMG/HFS archives
  * It's allowed to use -t switch for "list" and "extract" commands
  * Bug: wrong timestamp for files extracted from .zip or .rar archives
* Mon Jun 30 2008 mkoenig@suse.de
- update to version 4.58
  * Some speed optimizations
  * 7-Zip now can unpack .lzma archives
  * Unicode (UTF-8) support for filenames in .ZIP archives
  * Now it's possible to store file creation time in 7z and
    ZIP archives (-mtc switch)
  * 7-Zip now can unpack multivolume RAR archives created with
    "old style volume names" scheme and names *.001, *.002, ...
  * Now it's possible to use -mSW- and -mSW+ switches instead of
  - mSW=off and -mSW=on
* Thu Feb 28 2008 mkoenig@suse.de
- update to version 4.57
  * some minor bugfixes
* Tue Aug  7 2007 crrodriguez@suse.de
- update to version 4.51
  - fix built of test_emul
  - contrib/gzip-like_CLI_wrapper_for_7z/p7zip now supports commands like :
    p7zip -- -name
    p7zip "file name"
    p7zip file1 file2 file3
    p7zip -d file1.7z file2.7z file3.7z
  - some code cleanup
- run make test in the rpm check section
* Mon Jul  9 2007 mkoenig@suse.de
- update to version 4.48
  * bugfixes
* Mon Feb  5 2007 mkoenig@suse.de
- update to version 4.44:
  * fixes in the help displayed by 7za/7z/7zr.
  * code cleanup: remove of mySetModuleFileNameA (and its memory
    leak), GetModuleFileName ...
  Bugfixes:
  * in the plugins of 7z, the "Utf16" state was always off.
  * support for directory names that are not encoded
    with the current locale.
  * p7zip can now restore a symbolic link from a Zip archive
  * small fix in the output of the script install.sh
  * Extracting large directories takes quadratic time
  * Client7z added.
* Thu Dec 14 2006 mkoenig@suse.de
- update to version 4.43:
  * 7-Zip now can use multi-threading mode for compressing to
    .ZIP archives.
  * ZIP format supporting was improved.
  * 7-Zip now supports WinZip-compatible AES-256 encryption for
    .ZIP archives.
  * 7-Zip now uses order list (list of extensions) for files
    sorting for compressing to .7z archives.
  * 7-Zip now restores modification time of folders during .7z
    archives extracting.
* Thu Jun 29 2006 kssingvo@suse.de
- fixed specfile (makefile part) (bugzilla#187320)
* Wed Jun 21 2006 kssingvo@suse.de
- update to version 4.42
* Tue Apr 11 2006 kssingvo@suse.de
- update to version 4.37
* Fri Mar  3 2006 kssingvo@suse.de
- initial version
